coinor.blimpy.Stack'.Stack

Package coinor :: Package blimpy :: Module Stack' :: Class Stack |
[hide private]
[frames] | no frames]

# Class Stack

source code

This stack class is built on top of a linked list data structure.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__repr__(self) repr(x) | source code
__str__(self) str(x) | source code
isEmpty(self) | source code
peek(self, item=None) | source code
pop(self, item=None) | source code
push(self, item) | source code
remove(self, item) | source code
size(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)